*Budget shares for CPI

set more off


*Check if filepaths have been established using init.do
if "${gsdData}"=="" {
	display as error "Please run init.do first."
	error 1
}

* ----------------------------------------------------------------------------
* 2. Calculate budget shares by ITEM
* ----------------------------------------------------------------------------

* bring in NON_FOOD expenditures
use "${gsdData}/1-CleanInput/data_nf_proc.dta", clear
keep if (nonfoodid>=101 & nonfoodid<=425)

* Transform into monthly units
* 1 week recall (module C)
gen double nonfood=(S6_C03/1000)*((365/12)/7) 	if S6_C03_U==1 & (nonfoodid>=101 & nonfoodid<=110)
replace nonfood=S6_C03*((365/12)/7)	 			if S6_C03_U==2 & (nonfoodid>=101 & nonfoodid<=110)
replace nonfood=(S6_C03*1000)*((365/12)/7)		if S6_C03_U==3 & (nonfoodid>=101 & nonfoodid<=110)

* 1 month recall (module C)
replace	nonfood=S7_C06/1000 	if S7_C06_U==1 & (nonfoodid>=201 & nonfoodid<=226)
replace nonfood=S7_C06	    	if S7_C06_U==2 & (nonfoodid>=201 & nonfoodid<=226)
replace nonfood=S7_C06*1000		if S7_C06_U==3 & (nonfoodid>=201 & nonfoodid<=226)

* 3-month recall period (module D)
replace	nonfood=(S8_D03/1000)/3 	if S8_D03_U==1 & (nonfoodid>=301 & nonfoodid<=337)
replace nonfood=S8_D03/3	   		if S8_D03_U==2 & (nonfoodid>=301 & nonfoodid<=337)
replace nonfood=(S8_D03*1000)/3 	if S8_D03_U==3 & (nonfoodid>=301 & nonfoodid<=337)

* 12-month recall period (module E)
replace	nonfood=(S9_E03/1000)/12 	if S9_E03_U==1 & (nonfoodid>=401 & nonfoodid<=422)
replace nonfood=S9_E03/12			if S9_E03_U==2 & (nonfoodid>=401 & nonfoodid<=422)
replace nonfood=(S9_E03*1000)/12 	if S9_E03_U==3 & (nonfoodid>=401 & nonfoodid<=422)

* Items not purchased over past 12 months (in monthly units)
gen 	aux1=S10_E06/1000   if S10_E06_U==1
replace aux1=S10_E06		if S10_E06_U==2
replace aux1=S10_E06*1000 	if S10_E06_U==3

gen		aux2=S10_E07/1000   if S10_E07_U==1
replace aux2=S10_E07    	if S10_E07_U==2
replace aux2=S10_E07*1000 	if S10_E07_U==3

replace	nonfood=(aux1+aux2)/12 if (nonfoodid>=423 & nonfoodid<=425)
drop aux1 aux2

ren nonfood xnonfood
label var xnonfood "Total expenditure on nonfood items (1,000 shillings/household/month)"

drop if mi(xnonfood)
keep hhid nonfoodid xnonfood

* note: item code multiplied by 10 (to avoid confusion with food items)
replace nonfoodid = 10*nonfoodid

qui compress
save "${gsdData}/1-CleanTemp/non_food_CPI.dta", replace

* add FOOD expenditures
append using "${gsdData}/1-CleanTemp/food_consumption_clean.dta"
keep hhid nonfoodid foodid weight xfood xnonfood

gen itemid = .
replace itemid = foodid if !mi(foodid)
replace itemid = nonfoodid if !mi(nonfoodid) & mi(itemid)

assert !mi(itemid)

gen x = .
replace x = xfood 		if itemid <= 917
replace x = xnonfood 	if itemid >= 1010

sort hhid itemid

* keep URBAN household only
merge m:1 hhid using "${gsdData}/1-CleanTemp/wfilez.dta", keepusing(urban)
assert _merge == 3
drop _merge
keep if urban


keep hhid itemid x weight

* -----------------------------------------------------------------------------
* budget shares by item (PLUTOCRATIC)
preserve
* denominator
egen xden=total(x*weight) // where weight is the weight given to each household in the survey

* numerator
egen xnum=total(x*weight), by(itemid)

* ratio
gen w_pluto = xnum/xden

collapse (mean) w_pluto, by(itemid)

egen double check = total(w_pluto)
assert round(check, .0001) == 1
drop check

save "${gsdData}/1-CleanTemp/weights_CPI_pluto.dta", replace
restore

* -----------------------------------------------------------------------------
* budget shares by item (DEMOCRATIC)

preserve
* (...)
fillin hhid itemid
mvencode x, mv(0) override

* denominator
egen xden=total(x), by(hhid)

* numerator
egen xnum=total(x), by(itemid hhid)

* ratio
gen ratio = xnum/xden

* bring in weights
merge m:1 hhid using "${gsdData}/1-CleanTemp/wfilez.dta", keepusing(weight hsize)
keep if _merge == 3
drop _merge

* weight are individuals - see Deaton and Tarozzi' argument
collapse (mean) w_democ=ratio [aw=weight*hsize], by(itemid)

egen double check = total(w_democ)
*assert round(check, .0001) == 1
drop check

save "${gsdData}/1-CleanTemp/weights_CPI_democ.dta", replace
restore

use "${gsdData}/1-CleanTemp/weights_CPI_pluto.dta", clear
merge 1:1 itemid using "${gsdData}/1-CleanTemp/weights_CPI_democ.dta"
*assert _m == 3
drop _merge

format w* %9.4f

label var w_pluto "Budget share PLUTOCRATIC formula"
label var w_democ "Budget share DEMOCRATIC formula"

qui compress
save "${gsdData}/1-CleanTemp/weights_CPI.dta", replace

* Aggregation of budget shares according to sample.xlsx 
* See Ruth's email, Dec 16, 2014

gen str4 code = ""
* in SLHH there are '103=green maize cob', '104=maize, grain', and '105=maize, flour'
* there is no distinction between "A1= local" and "A2=import" as in CPI
replace code = "A1" if itemid == 103 
replace code = "A1" if itemid == 104
replace code = "A1" if itemid == 105

/*
replace code = "A2" if itemid == 103 
replace code = "A2" if itemid == 104
replace code = "A2" if itemid == 105
*/

replace code = "A3" if itemid == 108
replace code = "A5" if itemid == 102
replace code = "A6" if itemid == 111
replace code = "A7" if itemid == 110
replace code = "A8" if itemid == 113
replace code = "A9" if itemid == 119
replace code = "B10" if itemid == 503
replace code = "B11" if itemid == 502
replace code = "B12" if itemid == 501
* there is an error in CPI's file: both fish and goat meat 
* are coded as "B12". We recoded B13= Fish meat
replace code = "B13" if itemid == 511

replace code = "C13" if itemid == 704
* note: there is no 'camel milk' (C14) in SLHH
* note: there is only one 'milk powder' (C15) in SLHH

replace code = "C15" if itemid == 706
replace code = "C16" if itemid == 510

/* in SLHH 810 stands for "sesame/sunflower oil", 
which correspond both D17 and D18 in CPI, while 813 stands for 
"other cooking oil". Following Ruth's mail (Jan. 9), we 
provide aggregate weight for 'D=Oil' */
replace code = "D" if itemid == 810
replace code = "D" if itemid == 811
replace code = "D" if itemid == 813

replace code = "D19" if itemid == 812
replace code = "E20" if itemid == 404
replace code = "E21" if itemid == 410
replace code = "E22" if itemid == 601
* in the CPI file there are no codes for 'Orange', 'Date', 'Guava' and 'Apple'; 
* we assigned other 'E#' codes
replace code = "E30" if itemid == 602
* we matched 'E31=dates with 611=dried fruits
replace code = "E31" if itemid == 611
* in SLHH, 603='Grapefruits, lemons, guavas, limes'
replace code = "E32" if itemid == 603
*replace code = "E23" if itemid == 603
*replace code = "E24" if itemid == 603
replace code = "E33" if itemid == 610
replace code = "E25" if itemid == 605
replace code = "E26" if itemid == 307
replace code = "E27" if itemid == 201
replace code = "E28" if itemid == 411
replace code = "E29" if itemid == 414
replace code = "F30" if itemid == 807
replace code = "G31" if itemid == 901
replace code = "G32" if itemid == 909
* note: G33=cardamom is the only "other spice" (911) in CPI
replace code = "G33" if itemid == 911
replace code = "G34" if itemid == 902
replace code = "H35" if itemid == 903
* note: there is no 'Ice' (H36) in SLHH
replace code = "H37" if itemid == 905
replace code = "H38" if itemid == 1030

/* note: clothes are much more 'detailed' in CPI than 
in SLHH; therefore, we provide "aggregate" weights I, J 
and K, and "individual" weights for shoes (sandals are not
in the SLHH). alternatively, in the following lines we'll 
replace only for part of the codes in CPI */

* shoes
replace code = "I44" if itemid == 3190
replace code = "J51" if itemid == 3210
replace code = "K57" if itemid == 3180
replace code = "K57" if itemid == 3200

* I=clothes for men (excl. shoes)
replace code = "I" if itemid == 3070
replace code = "I" if itemid == 3080
replace code = "I" if itemid == 3090
replace code = "I" if itemid == 3100

* J=clothes for women (excl. shoes)
replace code = "J" if itemid == 3140
replace code = "J" if itemid == 3150
replace code = "J" if itemid == 3160
replace code = "J" if itemid == 3170

* K=clothes for children (infant, boys and girls)
replace code = "K" if itemid == 3010
* note: should we include baby nappies/diapers? in case..
* replace code = "K" if itemid == 302
replace code = "K" if itemid == 3030
replace code = "K" if itemid == 3040
replace code = "K" if itemid == 3050
replace code = "K" if itemid == 3060
replace code = "K" if itemid == 3110
replace code = "K" if itemid == 3120
replace code = "K" if itemid == 3130

/* otherwise..
replace code = "I41" if itemid == 3070
replace code = "J45" if itemid == 3170
* note: 316=lady's dress; sarl or frock?
replace code = "J46" if itemid == 3160
* replace code = "J47" if itemid == 3160
replace code = "K52" if itemid == 3040
replace code = "K53" if itemid == 3120
replace code = "K54" if itemid == 3030
*/

* note: there are no rent values in SLHH

* note: we coded M65=Electric
replace code = "M65" if itemid == 2260
replace code = "M61" if itemid == 1020
replace code = "M62" if itemid == 1010
replace code = "M63" if itemid == 2120

* note: in SLHH "212=petrol or diesel"
* replace code = "M64" if itemid == 2120
replace code = "N65" if itemid == 1080
replace code = "O81" if itemid == 5010
replace code = "O82" if itemid == 5040
replace code = "O83" if itemid == 5230
replace code = "P84" if itemid == 2200
replace code = "P85" if itemid == 1050
* note: in SLHH there is only '202=bar soap'
replace code = "P86" if itemid == 2020
* replace code = "S99" if itemid == 2020
* replace code = "S100" if itemid == 2020
* replace code = "S101" if itemid == 2020
* note: in SLHH there is no equivalent for 'P87=insecticides'
replace code = "P88" if itemid == 2030

* note: in SLHH there is only '422=health care expenses'; we code it as "Q"
replace code = "Q" if itemid == 4220

* note: there are no voices in SSLH on 'cinema' and 'SatTV room'
replace code = "V116" if itemid == 1100
replace code = "V117" if itemid == 802

collapse (sum) w*, by(code)

drop if mi(code)

* Rescale for budget shares to sum up to unity
egen sumwp= total(w_pluto)
egen sumwd= total(w_democ)

replace w_pluto = w_pluto/sumwp
replace w_democ = w_democ/sumwd

egen double check = total(w_democ)
assert round(check, .0001) == 1
drop check

egen double check = total(w_pluto)
assert round(check, .0001) == 1
drop check

drop sumwp sumwd

l, noo sep(0)
