*Nonfood aggregate

set more off


*Check if filepaths have been established using init.do
if "${gsdData}"=="" {
	display as error "Please run init.do first."
	error 1
}

use "${gsdData}/1-CleanInput/data_nf_proc.dta", clear

keep if (nonfoodid>=101 & nonfoodid<=425)

* ----------------------------------------------------------------------------
* Drop items which should not be included in the consumption aggregate

*drop if nonfoodid==110		// Qat (?)
drop if nonfoodid==216		// Mortgage
drop if nonfoodid==223		// Medical care items (health)
drop if nonfoodid==225		// Taxes
drop if nonfoodid==413		// Losses to theft
drop if nonfoodid==414		// Fines and legal fees (not welfare enhancing)
drop if nonfoodid==415		// Bridewealth cost
drop if nonfoodid==416		// Marriage ceremony cost
drop if nonfoodid==417		// Funeral cost (hh members)
drop if nonfoodid==418		// giving Zakat to the poor (in Sudan this was kind of a tax)
drop if nonfoodid==419		// Funeral cost (non hh members)
drop if nonfoodid==420		// Other celebration/ritual costs
drop if nonfoodid==422		// Healthcare expenses

* ----------------------------------------------------------------------------
* Transform into monthly units

* 1 week recall (module C)
gen double nonfood=(S6_C03/1000)*((365/12)/7) 	if S6_C03_U==1 & (nonfoodid>=101 & nonfoodid<=110)
replace nonfood=S6_C03*((365/12)/7)	 			if S6_C03_U==2 & (nonfoodid>=101 & nonfoodid<=110)
replace nonfood=(S6_C03*1000)*((365/12)/7)		if S6_C03_U==3 & (nonfoodid>=101 & nonfoodid<=110)

* 1 month recall (module C)
replace	nonfood=S7_C06/1000 	if S7_C06_U==1 & (nonfoodid>=201 & nonfoodid<=226)
replace nonfood=S7_C06	    	if S7_C06_U==2 & (nonfoodid>=201 & nonfoodid<=226)
replace nonfood=S7_C06*1000		if S7_C06_U==3 & (nonfoodid>=201 & nonfoodid<=226)

* 3-month recall period (module D)
replace	nonfood=(S8_D03/1000)/3 	if S8_D03_U==1 & (nonfoodid>=301 & nonfoodid<=337)
replace nonfood=S8_D03/3	   		if S8_D03_U==2 & (nonfoodid>=301 & nonfoodid<=337)
replace nonfood=(S8_D03*1000)/3 	if S8_D03_U==3 & (nonfoodid>=301 & nonfoodid<=337)

* 12-month recall period (module E)
replace	nonfood=(S9_E03/1000)/12 	if S9_E03_U==1 & (nonfoodid>=401 & nonfoodid<=422)
replace nonfood=S9_E03/12			if S9_E03_U==2 & (nonfoodid>=401 & nonfoodid<=422)
replace nonfood=(S9_E03*1000)/12 	if S9_E03_U==3 & (nonfoodid>=401 & nonfoodid<=422)

* Items not purchased over past 12 months (in monthly units)
gen 	aux1=S10_E06/1000   if S10_E06_U==1
replace aux1=S10_E06		if S10_E06_U==2
replace aux1=S10_E06*1000 	if S10_E06_U==3

gen		aux2=S10_E07/1000   if S10_E07_U==1
replace aux2=S10_E07    	if S10_E07_U==2
replace aux2=S10_E07*1000 	if S10_E07_U==3

replace	nonfood=(aux1+aux2)/12 if (nonfoodid>=423 & nonfoodid<=425)
drop aux1 aux2

ren nonfood xnonfood
label var xnonfood "Total expenditure on nonfood consumption (1,000 shillings/household/month)"


*Decide which version of the pipeline should be run
if ($run2016vs2013==1) {
	*Drop items to make 2012 and 2016 comparable 
	drop if nonfoodid==210
}


save "${gsdData}/1-CleanTemp/non_food_clean.dta", replace
