*Food spatial price index (Laspeyres): We estimate Laspeyres using democratic weights.
	
set more off


*Check if filepaths have been established using init.do
if "${gsdData}"=="" {
	display as error "Please run init.do first."
	error 1
}

* Code urban/rural
use "${gsdData}/1-CleanTemp/food_consumption_clean.dta", clear
gen urban=0 if strata==2
replace urban=1 if strata==1 | strata==3 
label var urban " = 1 if urban, o if rural"
label def urban 1 "urban" 0 "rural"
label val urban urban

* ----------------------------------------------------------------------------
* 2. Calculate DEMOCRATIC budget shares
* ----------------------------------------------------------------------------

assert !mi(xfood)

*add zero consumption 
keep hhid weight region district strata urban foodid xfood uv
reshape wide xfood uv, i(hhid weight region district strata urban) j(foodid)
foreach v of var xfood* {
	quiet: replace `v' = 0 if `v'>=.
}
reshape long xfood uv, i(hhid weight region district strata urban) j(foodid)

*share per household
egen xfoodhh = total(xfood), by(hhid)
gen wfoodhh = xfood/xfoodhh
*raise to hh weight but only for urban used as reference
gen rwfoodhh = wfoodhh * weight if urban
gen wurban = weight if urban

*calculate budget share for reference (urban)
egen xfoodd = total(rwfoodhh), by(foodid)
egen sumxd = total(wurban), by(foodid)
gen double wfood = (xfoodd/sumxd)
label var wfood "democratic budget share"

* check district-level budget shares add up to one
preserve
collapse (firstnm) wfood, by(foodid)
egen x = total(wfood)
assert round(x,0.001)==1
restore

* check no budget share is missing
assert !mi(wfood)

* ----------------------------------------------------------------------------
* 3. Construct Laspeyres index
* ----------------------------------------------------------------------------

*reference price vector
* calculate p_0 (urban *median* unit values by fooditem)
* weights: households
levelsof foodid, local(food)
local lf = ""
foreach f of local food {
	qui sum uv [aw = weight] if foodid == `f' & urban, detail
	gen pz`f'med = r(p50)
	*drop producs not consumed by any urban household
	if mi(pz`f'med) drop pz`f'med
	else local lf = "`lf' `f'"
}

* median uv by food item and district
preserve
collapse (median) uvdist=uv [aweight=weight], by(district foodid urban)
label var uvdist "unit value by district"
save "${gsdData}/1-CleanTemp/med_uvdist.dta", replace
restore

merge m:1 district foodid urban using "${gsdData}/1-CleanTemp/med_uvdist.dta", keep(master match) nogen

* The formula of Laspeyres index as from Deaton and Zaidi
foreach f of local lf {
	qui gen double uvz`f'med  = wfood*(uvdist/pz`f'med) if foodid == `f'
}
collapse (firstnm) uvz*med region, by(district urban)
egen    paaschemed = rowtotal(uvz*med) 
replace paaschemed = 1/paaschemed
la var  paaschemed "Laspeyres index"
label val district DIST
keep district urban paaschemed
sort district urban
list

*save files (compatible with previous code)
save "${gsdData}/1-CleanTemp/paasche.dta", replace
export excel using "${gsdOutput}/spi.xlsx", sheet("Raw") sheetreplace first(var)
*save urban districts
drop if !urban
ren paaschemed paasche_u
save "${gsdData}/1-CleanTemp/paasche_u.dta", replace
*save rural districts
use "${gsdData}/1-CleanTemp/paasche.dta", clear
drop if urban
ren paaschemed paasche_r
save "${gsdData}/1-CleanTemp/paasche_r.dta", replace
